/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { DistributionWidgetDefinitionType } from "./DistributionWidgetDefinitionType";
import { DistributionWidgetRequest } from "./DistributionWidgetRequest";
import { DistributionWidgetXAxis } from "./DistributionWidgetXAxis";
import { DistributionWidgetYAxis } from "./DistributionWidgetYAxis";
import { WidgetCustomLink } from "./WidgetCustomLink";
import { WidgetMarker } from "./WidgetMarker";
import { WidgetTextAlign } from "./WidgetTextAlign";
import { WidgetTime } from "./WidgetTime";
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * The Distribution visualization is another way of showing metrics
 * aggregated across one or several tags, such as hosts.
 * Unlike the heat map, a distribution graph’s x-axis is quantity rather than time.
 */
export declare class DistributionWidgetDefinition {
    /**
     * A list of custom links.
     */
    "customLinks"?: Array<WidgetCustomLink>;
    /**
     * (Deprecated) The widget legend was replaced by a tooltip and sidebar.
     */
    "legendSize"?: string;
    /**
     * List of markers.
     */
    "markers"?: Array<WidgetMarker>;
    /**
     * Array of one request object to display in the widget.
     *
     * See the dedicated [Request JSON schema documentation](https://docs.datadoghq.com/dashboards/graphing_json/request_json)
     *  to learn how to build the `REQUEST_SCHEMA`.
     */
    "requests": [DistributionWidgetRequest];
    /**
     * (Deprecated) The widget legend was replaced by a tooltip and sidebar.
     */
    "showLegend"?: boolean;
    /**
     * Time setting for the widget.
     */
    "time"?: WidgetTime;
    /**
     * Title of the widget.
     */
    "title"?: string;
    /**
     * How to align the text on the widget.
     */
    "titleAlign"?: WidgetTextAlign;
    /**
     * Size of the title.
     */
    "titleSize"?: string;
    /**
     * Type of the distribution widget.
     */
    "type": DistributionWidgetDefinitionType;
    /**
     * X Axis controls for the distribution widget.
     */
    "xaxis"?: DistributionWidgetXAxis;
    /**
     * Y Axis controls for the distribution widget.
     */
    "yaxis"?: DistributionWidgetYAxis;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
