/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { LogsDailyLimitReset } from "./LogsDailyLimitReset";
import { LogsExclusion } from "./LogsExclusion";
import { LogsFilter } from "./LogsFilter";
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * Object describing a Datadog Log index.
 */
export declare class LogsIndex {
    /**
     * The number of log events you can send in this index per day before you are rate-limited.
     */
    "dailyLimit"?: number;
    /**
     * Object containing options to override the default daily limit reset time.
     */
    "dailyLimitReset"?: LogsDailyLimitReset;
    /**
     * A percentage threshold of the daily quota at which a Datadog warning event is generated.
     */
    "dailyLimitWarningThresholdPercentage"?: number;
    /**
     * An array of exclusion objects. The logs are tested against the query of each filter,
     * following the order of the array. Only the first matching active exclusion matters,
     * others (if any) are ignored.
     */
    "exclusionFilters"?: Array<LogsExclusion>;
    /**
     * Filter for logs.
     */
    "filter": LogsFilter;
    /**
     * A boolean stating if the index is rate limited, meaning more logs than the daily limit have been sent.
     * Rate limit is reset every-day at 2pm UTC.
     */
    "isRateLimited"?: boolean;
    /**
     * The name of the index.
     */
    "name": string;
    /**
     * The total number of days logs are stored in Standard and Flex Tier before being deleted from the index.
     * If Standard Tier is enabled on this index, logs are first retained in Standard Tier for the number of days specified through `num_retention_days`,
     * and then stored in Flex Tier until the number of days specified in `num_flex_logs_retention_days` is reached.
     * The available values depend on retention plans specified in your organization's contract/subscriptions.
     */
    "numFlexLogsRetentionDays"?: number;
    /**
     * The number of days logs are stored in Standard Tier before aging into the Flex Tier or being deleted from the index.
     * The available values depend on retention plans specified in your organization's contract/subscriptions.
     */
    "numRetentionDays"?: number;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
