/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { MonthlyUsageAttributionValues } from "./MonthlyUsageAttributionValues";
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * Usage Summary by tag for a given organization.
 */
export declare class MonthlyUsageAttributionBody {
    /**
     * Datetime in ISO-8601 format, UTC, precise to month: [YYYY-MM].
     */
    "month"?: Date;
    /**
     * The name of the organization.
     */
    "orgName"?: string;
    /**
     * The organization public ID.
     */
    "publicId"?: string;
    /**
     * The region of the Datadog instance that the organization belongs to.
     */
    "region"?: string;
    /**
     * The source of the usage attribution tag configuration and the selected tags in the format `<source_org_name>:::<selected tag 1>///<selected tag 2>///<selected tag 3>`.
     */
    "tagConfigSource"?: string;
    /**
     * Tag keys and values.
     *
     * A `null` value here means that the requested tag breakdown cannot be applied because it does not match the [tags
     * configured for usage attribution](https://docs.datadoghq.com/account_management/billing/usage_attribution/#getting-started).
     * In this scenario the API returns the total usage, not broken down by tags.
     */
    "tags"?: {
        [key: string]: Array<string>;
    };
    /**
     * Datetime of the most recent update to the usage values.
     */
    "updatedAt"?: Date;
    /**
     * Fields in Usage Summary by tag(s).
     */
    "values"?: MonthlyUsageAttributionValues;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
