/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { NotebookCellTime } from "./NotebookCellTime";
import { NotebookGraphSize } from "./NotebookGraphSize";
import { NotebookSplitBy } from "./NotebookSplitBy";
import { TimeseriesWidgetDefinition } from "./TimeseriesWidgetDefinition";
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * The attributes of a notebook `timeseries` cell.
 */
export declare class NotebookTimeseriesCellAttributes {
    /**
     * The timeseries visualization allows you to display the evolution of one or more metrics, log events, or Indexed Spans over time.
     */
    "definition": TimeseriesWidgetDefinition;
    /**
     * The size of the graph.
     */
    "graphSize"?: NotebookGraphSize;
    /**
     * Object describing how to split the graph to display multiple visualizations per request.
     */
    "splitBy"?: NotebookSplitBy;
    /**
     * Timeframe for the notebook cell. When 'null', the notebook global time is used.
     */
    "time"?: NotebookCellTime;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
