/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { SplitConfig } from "./SplitConfig";
import { SplitGraphSourceWidgetDefinition } from "./SplitGraphSourceWidgetDefinition";
import { SplitGraphVizSize } from "./SplitGraphVizSize";
import { SplitGraphWidgetDefinitionType } from "./SplitGraphWidgetDefinitionType";
import { WidgetTime } from "./WidgetTime";
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * The split graph widget allows you to create repeating units of a graph - one for each value in a group (for example: one per service)
 */
export declare class SplitGraphWidgetDefinition {
    /**
     * Normalize y axes across graphs
     */
    "hasUniformYAxes"?: boolean;
    /**
     * Size of the individual graphs in the split.
     */
    "size": SplitGraphVizSize;
    /**
     * The original widget we are splitting on.
     */
    "sourceWidgetDefinition": SplitGraphSourceWidgetDefinition;
    /**
     * Encapsulates all user choices about how to split a graph.
     */
    "splitConfig": SplitConfig;
    /**
     * Time setting for the widget.
     */
    "time"?: WidgetTime;
    /**
     * Title of your widget.
     */
    "title"?: string;
    /**
     * Type of the split graph widget
     */
    "type": SplitGraphWidgetDefinitionType;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
