/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { SyntheticsBrowserVariableType } from "./SyntheticsBrowserVariableType";
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * Object defining a variable that can be used in your browser test.
 * See the [Recording Steps documentation](https://docs.datadoghq.com/synthetics/browser_tests/actions/?tab=testanelementontheactivepage#variables).
 */
export declare class SyntheticsBrowserVariable {
    /**
     * Example for the variable.
     */
    "example"?: string;
    /**
     * ID for the variable. Global variables require an ID.
     */
    "id"?: string;
    /**
     * Name of the variable.
     */
    "name": string;
    /**
     * Pattern of the variable.
     */
    "pattern"?: string;
    /**
     * Determines whether or not the browser test variable is obfuscated. Can only be used with browser variables of type `text`.
     */
    "secure"?: boolean;
    /**
     * Type of browser test variable.
     */
    "type": SyntheticsBrowserVariableType;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
