/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * Object containing all metrics and their values collected for a Synthetic API test.
 * See the [Synthetic Monitoring Metrics documentation](https://docs.datadoghq.com/synthetics/metrics/).
 */
export declare class SyntheticsTiming {
    /**
     * The duration in millisecond of the DNS lookup.
     */
    "dns"?: number;
    /**
     * The time in millisecond to download the response.
     */
    "download"?: number;
    /**
     * The time in millisecond to first byte.
     */
    "firstByte"?: number;
    /**
     * The duration in millisecond of the TLS handshake.
     */
    "handshake"?: number;
    /**
     * The time in millisecond spent during redirections.
     */
    "redirect"?: number;
    /**
     * The duration in millisecond of the TLS handshake.
     */
    "ssl"?: number;
    /**
     * Time in millisecond to establish the TCP connection.
     */
    "tcp"?: number;
    /**
     * The overall time in millisecond the request took to be processed.
     */
    "total"?: number;
    /**
     * Time spent in millisecond waiting for a response.
     */
    "wait"?: number;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
