/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { ToplistWidgetDefinitionType } from "./ToplistWidgetDefinitionType";
import { ToplistWidgetRequest } from "./ToplistWidgetRequest";
import { ToplistWidgetStyle } from "./ToplistWidgetStyle";
import { WidgetCustomLink } from "./WidgetCustomLink";
import { WidgetTextAlign } from "./WidgetTextAlign";
import { WidgetTime } from "./WidgetTime";
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * The top list visualization enables you to display a list of Tag value like hostname or service with the most or least of any metric value, such as highest consumers of CPU, hosts with the least disk space, etc.
 */
export declare class ToplistWidgetDefinition {
    /**
     * List of custom links.
     */
    "customLinks"?: Array<WidgetCustomLink>;
    /**
     * List of top list widget requests.
     */
    "requests": Array<ToplistWidgetRequest>;
    /**
     * Style customization for a top list widget.
     */
    "style"?: ToplistWidgetStyle;
    /**
     * Time setting for the widget.
     */
    "time"?: WidgetTime;
    /**
     * Title of your widget.
     */
    "title"?: string;
    /**
     * How to align the text on the widget.
     */
    "titleAlign"?: WidgetTextAlign;
    /**
     * Size of the title.
     */
    "titleSize"?: string;
    /**
     * Type of the top list widget.
     */
    "type": ToplistWidgetDefinitionType;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
