/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { CustomDestinationAttributeTagsRestrictionListType } from "./CustomDestinationAttributeTagsRestrictionListType";
import { CustomDestinationForwardDestination } from "./CustomDestinationForwardDestination";
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * The attributes associated with the custom destination.
 */
export declare class CustomDestinationUpdateRequestAttributes {
    /**
     * Whether logs matching this custom destination should be forwarded or not.
     */
    "enabled"?: boolean;
    /**
     * Whether tags from the forwarded logs should be forwarded or not.
     */
    "forwardTags"?: boolean;
    /**
     * List of [keys of tags](https://docs.datadoghq.com/getting_started/tagging/#define-tags) to be restricted from being forwarded.
     * An empty list represents no restriction is in place and either all or no tags will be forwarded depending on `forward_tags_restriction_list_type` parameter.
     */
    "forwardTagsRestrictionList"?: Array<string>;
    /**
     * How `forward_tags_restriction_list` parameter should be interpreted.
     * If `ALLOW_LIST`, then only tags whose keys on the forwarded logs match the ones on the restriction list
     * are forwarded.
     *
     * `BLOCK_LIST` works the opposite way. It does not forward the tags matching the ones on the list.
     */
    "forwardTagsRestrictionListType"?: CustomDestinationAttributeTagsRestrictionListType;
    /**
     * A custom destination's location to forward logs.
     */
    "forwarderDestination"?: CustomDestinationForwardDestination;
    /**
     * The custom destination name.
     */
    "name"?: string;
    /**
     * The custom destination query and filter. Logs matching this query are forwarded to the destination.
     */
    "query"?: string;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
