/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * Logs that are sent over HTTP.
 */
export declare class HTTPLogItem {
    /**
     * The integration name associated with your log: the technology from which the log originated.
     * When it matches an integration name, Datadog automatically installs the corresponding parsers and facets.
     * See [reserved attributes](https://docs.datadoghq.com/logs/log_configuration/attributes_naming_convention/#reserved-attributes).
     */
    "ddsource"?: string;
    /**
     * Tags associated with your logs.
     */
    "ddtags"?: string;
    /**
     * The name of the originating host of the log.
     */
    "hostname"?: string;
    /**
     * The message [reserved attribute](https://docs.datadoghq.com/logs/log_configuration/attributes_naming_convention/#reserved-attributes)
     * of your log. By default, Datadog ingests the value of the message attribute as the body of the log entry.
     * That value is then highlighted and displayed in the Logstream, where it is indexed for full text search.
     */
    "message": string;
    /**
     * The name of the application or service generating the log events.
     * It is used to switch from Logs to APM, so make sure you define the same value when you use both products.
     * See [reserved attributes](https://docs.datadoghq.com/logs/log_configuration/attributes_naming_convention/#reserved-attributes).
     */
    "service"?: string;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
