/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * Optional parameters for bulk creating metric tag configurations.
 */
export declare class MetricBulkTagConfigCreateAttributes {
    /**
     * A list of account emails to notify when the configuration is applied.
     */
    "emails"?: Array<string>;
    /**
     * When set to true, the configuration will exclude the configured tags and include any other submitted tags.
     * When set to false, the configuration will include the configured tags and exclude any other submitted tags.
     * Defaults to false.
     */
    "excludeTagsMode"?: boolean;
    /**
     * When provided, all tags that have been actively queried are
     * configured (and, therefore, remain queryable) for each metric that
     * matches the given prefix.  Minimum value is 1 second, and maximum
     * value is 7,776,000 seconds (90 days).
     */
    "includeActivelyQueriedTagsWindow"?: number;
    /**
     * When set to true, the configuration overrides any existing
     * configurations for the given metric with the new set of tags in this
     * configuration request. If false, old configurations are kept and
     * are merged with the set of tags in this configuration request.
     * Defaults to true.
     */
    "overrideExistingConfigurations"?: boolean;
    /**
     * A list of tag names to apply to the configuration.
     */
    "tags"?: Array<string>;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
