/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { NotificationRuleAttributes } from "./NotificationRuleAttributes";
import { NotificationRulesType } from "./NotificationRulesType";
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * Notification rules allow full control over notifications generated by the various Datadog security products.
 * They allow users to define the conditions under which a notification should be generated (based on rule severities,
 * rule types, rule tags, and so on), and the targets to notify.
 * A notification rule is composed of a rule ID, a rule type, and the rule attributes. All fields are required.
 */
export declare class NotificationRule {
    /**
     * Attributes of the notification rule.
     */
    "attributes": NotificationRuleAttributes;
    /**
     * The ID of a notification rule.
     */
    "id": string;
    /**
     * The rule type associated to notification rules.
     */
    "type": NotificationRulesType;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
