/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { ObservabilityPipelineAddFieldsProcessorType } from "./ObservabilityPipelineAddFieldsProcessorType";
import { ObservabilityPipelineFieldValue } from "./ObservabilityPipelineFieldValue";
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * The `add_fields` processor adds static key-value fields to logs.
 */
export declare class ObservabilityPipelineAddFieldsProcessor {
    /**
     * A list of static fields (key-value pairs) that is added to each log event processed by this component.
     */
    "fields": Array<ObservabilityPipelineFieldValue>;
    /**
     * The unique identifier for this component. Used to reference this component in other parts of the pipeline (for example, as the `input` to downstream components).
     */
    "id": string;
    /**
     * A Datadog search query used to determine which logs this processor targets.
     */
    "include": string;
    /**
     * A list of component IDs whose output is used as the `input` for this component.
     */
    "inputs": Array<string>;
    /**
     * The processor type. The value should always be `add_fields`.
     */
    "type": ObservabilityPipelineAddFieldsProcessorType;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
