/**
 * Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
 * This product includes software developed at Datadog (https://www.datadoghq.com/).
 * Copyright 2020-Present Datadog, Inc.
 */
import { SLOReportInterval } from "./SLOReportInterval";
import { AttributeTypeMap } from "../../datadog-api-client-common/util";
/**
 * The attributes portion of the SLO report request.
 */
export declare class SloReportCreateRequestAttributes {
    /**
     * The `from` timestamp for the report in epoch seconds.
     */
    "fromTs": number;
    /**
     * The frequency at which report data is to be generated.
     */
    "interval"?: SLOReportInterval;
    /**
     * The query string used to filter SLO results. Some examples of queries include `service:<service-name>` and `slo-name`.
     */
    "query": string;
    /**
     * The timezone used to determine the start and end of each interval. For example, weekly intervals start at 12am on Sunday in the specified timezone.
     */
    "timezone"?: string;
    /**
     * The `to` timestamp for the report in epoch seconds.
     */
    "toTs": number;
    /**
     * A container for additional, undeclared properties.
     * This is a holder for any undeclared properties as specified with
     * the 'additionalProperties' keyword in the OAS document.
     */
    "additionalProperties"?: {
        [key: string]: any;
    };
    /**
     * @ignore
     */
    "_unparsed"?: boolean;
    /**
     * @ignore
     */
    static readonly attributeTypeMap: AttributeTypeMap;
    /**
     * @ignore
     */
    static getAttributeTypeMap(): AttributeTypeMap;
    constructor();
}
